/*
   The basic structure of a GRS file is:
   1.) A number of comment lines, followed by a line starting with an asterisk, '*'.
   2.) The "extent" of the figure in world coordinates (left, top, right, bottom).
   3.) The number of polylines in the figure.
   4.) The list of polylines. Each polyline starts with the number of points in the
       polyline, followed by the (x, y) world coordinates for each point.
*/
#include <windows.h>
#include <iostream>
#include <fstream>
#include "glut.h"

using namespace std;

//<<<<<<<<<<<<<<<<<<<<<<<<<<< setWindow >>>>>>>>>>>>>>>>>>>>>>>>>>>
void setWindow(GLdouble left, GLdouble right, GLdouble bottom, GLdouble top)
{
   glMatrixMode(GL_PROJECTION);        // define window
   glLoadIdentity();
   gluOrtho2D(left, right, bottom, top);
}

//<<<<<<<<<<<<<<<<<<<<<< drawGRSFile >>>>>>>>>>>>>>>>>>>>>>
void drawGRSFile(char *fileName)
{
   fstream inStream;
   inStream.open(fileName, ios::in);  // open the GRS file
   if(inStream.fail()) {cout << "can't open GRS file!"; return;};

   // read the comment lines
   char str[80];
   inStream.getline(str, 80, '\n');
   while (str[0] != '*')
      inStream.getline(str, 80, '\n');

   // read the figure extents
   GLdouble left, top, right, bottom;
   inStream >> left >> top >> right >> bottom;

   // set the world window to just hold the image from the GRS file
   setWindow(left, right, bottom, top);

   GLint numpolys;
   inStream >> numpolys;              // read the number of polylines
   for(int j = 0; j < numpolys; j++)  // read each polyline
   {
      GLint numLines;
      inStream >> numLines;           // read the number vertices in this polyline
      GLfloat x ,y;
      glBegin(GL_LINE_STRIP);         // draw the next polyline
        for (int i = 0; i < numLines; i++)
        {
           inStream >> x >> y;        // read the next world coordinate pair
           glVertex2f(x, y);
        }
      glEnd();
   }
   glFlush();  // forces the drawing to take place
   inStream.close();
}

//<<<<<<<<<<<<<<<<<<<<<<<<<<< display >>>>>>>>>>>>>>>>>>>>>>>>>>>
void display(void)
{
   glClear(GL_COLOR_BUFFER_BIT);   // clear screen

   drawGRSFile("bronto.grs");
}

//<<<<<<<<<<<<<<<<<<<<<<<<<<< myInit >>>>>>>>>>>>>>>>>>>>>>>>>>>.
void myInit(void)
{
   glClearColor(1.0f,1.0f,1.0f,1.0f);  // background is white
   glColor3f(0.0f,0.0f,0.0f);          // set color of stuff
   glMatrixMode(GL_PROJECTION);        // define window
   glLoadIdentity();
   gluOrtho2D(0, 640.0, 0, 480.0);
}

//<<<<<<<<<<<<<<<<<<<<<< main >>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>
int main(int argc, char **argv)
{
   glutInit(&argc, argv);
   glutInitDisplayMode(GLUT_SINGLE | GLUT_RGB);
   glutInitWindowSize(640,480); // open a 640 by 480 window
   glutInitWindowPosition(100, 100);
   glutCreateWindow("GRS file");
   glutDisplayFunc(display);
   myInit();
   glutMainLoop();
   return 0;
}